==> vtigercrm-5.3.0p0.tgz: modules/MailManager/language/en_us.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.1
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$mod_strings = Array (
	'MailManager' => 'Mail Manager',
	
	// Translations for JS (please use the prefix JSLBL in key)
	'JSLBL_Loading_Please_Wait'  => 'Loading Please Wait',
	'JSLBL_Loading'              => 'Loading',
	'JSLBL_Settings'             => 'Settings',
	'JSLBL_Opening'              => 'Opening',
	'JSLBL_Deleting'              => 'Deleting',  
	'JSLBL_Updating'             => 'Updating',
	'JSLBL_Associating'          => 'Associating',
	'JSLBL_Saving_And_Verifying' => 'Saving & Verifying',
	'JSLBL_Failed_To_Open_Mail'  => 'Failed to open the mail',
	'JSLBL_Finding_Relation'     => 'Finding relation',
	'JSLBL_Find_Relation_Now'    => 'Find relation now',
	'JSLBL_Searching'            => 'Searching',
	'JSLBL_Searching_Please_Wait'=> 'Searching Please Wait',
	'JSLBL_Sending'              => 'Sending',
	'JSLBL_Replied'              => 'Replied',
	'JSLBL_Failed_To_Send_Mail'  => 'Failed to send the mail',
	'JSLBL_Recepient_Cannot_Be_Empty' => 'Recepient cannot be empty',
	'JSLBL_SendWith_EmptySubject'     => 'Send with subject empty?',
	'JSLBL_Removing'                  => 'Removing',
	'JSLBL_Choose_Server_Type'        => 'Choose server type',
	'JSLBL_Other'                     => 'Other',
	'JSLBL_Gmail'                     => 'Gmail',
	'JSLBL_Fastmail'                  => 'Fastmail',
	'JSLBL_Search_For_Email'          => 'Search for email',
	'JSLBL_Nothing_Found'             => 'Nothing found',
	'JSLBL_Delete_Confirm'            =>'Do you want to delete the Emails permanently?',
	'JSLBL_Delete_Mails_Confirm'      =>'Do you want to delete the Emails?',
	'JSLBL_Receipents_Warning_Message'=>'Please select recepients',
	'JSLBL_NO_MATCH'				  => 'No match found',
	'JSLBL_Saving'					=> 'Saving',
	'JSLBL_Failed_To_Save_Mail'		=>	'Failed to save the mail',
	'JSLBL_ATTACHMENT_NOT_DELETED'	=>	'Attachment could not be deleted',
	'JSLBL_UPLOAD_CANCEL'	=> 'Cancel',
	'JSLBL_UPLOAD_DROPFILES'=>'Drop files here to upload',
	'JSLBL_UPLOAD_FILE'=>'Upload',
	'JSLBL_UPLOAD_DELETE'=>'[x]',
	'JSLBL_UPLOAD_FAILED'=>'Failed',
	'JSLBL_FILEUPLOAD_LIMIT_EXCEEDED'=>'File Upload Limit exceeded!!',
	'JSLBL_MAIL_SENT'=>'Mail Sent',
	'JSLBL_EMAIL_FORMAT_INCORRECT'=>'Please provide proper email address',
	'JSLBL_Saving'=>'Saving',
	'JSLBL_SaveWith_EmptySubject'=>'Save with subject empty?',
	'JSLBL_Delete'            =>  'Delete',
	'JSLBL_Drafts'=>'Drafts',
	'JSLBL_PASSWORD_CANNOT_BE_EMPTY'=>'Password cannot be empty',
	'JSLBL_SERVERNAME_CANNOT_BE_EMPTY'=>'Server Name cannot be empty',
	'JSLBL_USERNAME_CANNOT_BE_EMPTY'=>'User Name cannot be empty',
	'JSLBL_ACCOUNTNAME_CANNOT_EMPTY'=>'Account Name cannot be empty',
	'JSLBL_FROM'=>'From:',
	'JSLBL_DATE'=>'Date: ',
	'JSLBL_SUBJECT'=>'Subject: ',
	'JSLBL_TO'=>'To: ',
	'JSLBL_CC'=>'Cc: ',
	'JSLBL_FORWARD_MESSAGE_TEXT'=>'---------- Forwarded message ----------',
	'JSLBL_PLEASE_SELECT_ATLEAST_ONE_MAIL'=>'Please select at least one mail',
	'JSLBL_PLEASE_SELECT_ATLEAST_ONE_RECORD'=>'Please select at least one record',
	'JSLBL_MAIL_MOVED'=>'Mail(s) moved',
	'JSLBL_MOVING'=>'Moving Mail(s)',
	'JSLBL_LOADING_FOLDERS' => 'Loading Folders..',
	'JSLBL_ADD_COMMENT'=>'Add Comment',
    'JSLBL_Yahoo'=>'Yahoo',
    'JSLBL_CANNOT_ADD_EMPTY_COMMENT' => 'Comment cannot be empty',
    'JSLBL_NO_EMAILS_SELECTED' => 'No Emails Selected.',
    'JSLBL_ENTER_SOME_VALUE' => 'Enter some string to search',
    'JSLBL_DRAFT_MAIL_SAVED'=>'Mail is saved under Drafts',
    
	// General translations
	'LBL_Folders'         => 'Folders',
	'LBL_Newer'           => 'Newer',
	'LBL_Older'           => 'Older',
	'LBL_No_Mails_Found'  => 'No mails found.',
	'LBL_Go_Back'         => 'Back',
	'LBL_Reply_All'       => 'Reply all',
	'LBL_Reply'           => 'Reply',
	'LBL_Mark_As_Unread'  => 'Mark as unread',
	'LBL_Previous'        => 'previous',
	'LBL_Next'            => 'next',
	'LBL_RELATED_RECORDS' => 'Related Records',
	'LBL_Mailbox'         => 'Mailbox',
	'LBL_Outbox'          => 'CRM Outbox',
	'LBL_Like'            => 'like',
	'LBL_Mail_Server'     => 'Mail Server Name or IP',
	'LBL_Refresh'         => 'Refresh',
	'LBL_Cancel'          => 'Cancel',
	'LBL_Send'            => 'Send',
	'LBL_Compose'         => 'Compose',
	'LBL_Forward'         => 'Forward',
	'LBL_Remove'          => 'Remove',
	'LBL_Associate'       => 'Associate',
	'LBL_Create_Contact'  => 'Create contact',
	'LBL_No_Matching_Record_Found' => 'No matching records found.',
	'LBL_ACTIONS'         => 'Actions',
	'LBL_Search'          => 'Search',
	'LBL_Delete'            =>  'Delete',
	
	'LBL_Username'             => 'User Name',
	'LBL_Your_Mailbox_Account' => 'your mailbox account',
	'LBL_Password'             => 'Password',
	'LBL_Account_Password'     => 'account password',
	'LBL_Protocol'    => 'Protocol',
	'LBL_Imap2'       => 'IMAP2',
	'LBL_Imap4'       => 'IMAP4',
	'LBL_SSL_Options' => 'SSL Options',
	'LBL_No_TLS'      => 'No TLS',
	'LBL_TLS'         => 'TLS',
	'LBL_SSL'         => 'SSL',
	'LBL_Certificate_Validations' => 'Certificate Validations',
	'LBL_Validate_Cert'           => 'Validate cert',
	'LBL_Do_Not_Validate_Cert'    => 'Do not validate cert',
	'LBL_SELECT_ACCOUNT_TYPE'     => 'Select Account Type',
	
	'LBL_FROM'        => 'From',
	'LBL_TO'          => 'To',
	'LBL_CC'          => 'CC',
	'LBL_BCC'         => 'BCC',
	'LBL_Date'        => 'Date',
	'LBL_Attachments' => 'Attachments',
	'LBL_EMAIL_TEMPLATES_LIST'=>'Email Templates',
	'LBL_SELECT_EMAIL_TEMPLATE'=>'Select Email template',
	'LBL_ATTACHMENTS'  =>'Attachment:',
	'LBL_SELECT_DOCUMENTS'=>'Select Documents',
	'LBL_IN' =>'in',
	'LBL_FIND'=>'Find',
	'LBL_SAVE_NOW'=>'Save Now',
	'LBL_Drafts'=>'Drafts',
 	'LBL_NO_EMAILS_SELECTED' => 'No Emails Selected.',
	'LBL_SUBJECT'	=>	'Subject',
	'LBL_WRITE_ACCESS_FOR'	=>'Write access for',
	'LBL_READ_ACCESS_FOR'	=>'Read access for',
	'LBL_MODULE_DENIED' => 'module denied!',
	'LBL_REFRESH_TIME'=>'Refresh Time',
	'LBL_NONE' => 'None',
	'LBL_5_MIN' => '5 Minutes',
	'LBL_10_MIN' => '10 Minutes',
	'LBL_MOVE_TO'=>'Move To...',
    'LBL_MAILMANAGER_ADD_Contacts' => 'Add Contact',
    'LBL_MAILMANAGER_ADD_Accounts' => 'Add Account',
    'LBL_MAILMANAGER_ADD_Leads' => 'Add Lead',
    'LBL_MAILMANAGER_ADD_Calendar' => 'Add ToDo',
    'LBL_MAILMANAGER_ADD_HelpDesk' => 'Add Ticket',
    'LBL_MAILMANAGER_ADD_Emails' => 'Attach Email',
    'LBL_MAILMANAGER_ADD_ModComments' => 'Add Comment',
    'LBL_ADD' => 'Add'
);

?>

==> vtigercrm-5.4.0.tgz: modules/MailManager/language/en_us.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.1
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$mod_strings = Array (
	'MailManager' => 'Mail Manager',
	
	// Translations for JS (please use the prefix JSLBL in key)
	'JSLBL_Loading_Please_Wait'  => 'Loading Please Wait',
	'JSLBL_Loading'              => 'Loading',
	'JSLBL_Settings'             => 'Settings',
	'JSLBL_Opening'              => 'Opening',
	'JSLBL_Deleting'              => 'Deleting',  
	'JSLBL_Updating'             => 'Updating',
	'JSLBL_Associating'          => 'Associating',
	'JSLBL_Saving_And_Verifying' => 'Saving & Verifying',
	'JSLBL_Failed_To_Open_Mail'  => 'Failed to open the mail',
	'JSLBL_Finding_Relation'     => 'Finding relation',
	'JSLBL_Find_Relation_Now'    => 'Find relation now',
	'JSLBL_Searching'            => 'Searching',
	'JSLBL_Searching_Please_Wait'=> 'Searching Please Wait',
	'JSLBL_Sending'              => 'Sending',
	'JSLBL_Replied'              => 'Replied',
	'JSLBL_Failed_To_Send_Mail'  => 'Failed to send the mail',
	'JSLBL_Recepient_Cannot_Be_Empty' => 'Recepient cannot be empty',
	'JSLBL_SendWith_EmptySubject'     => 'Send with subject empty?',
	'JSLBL_Removing'                  => 'Removing',
	'JSLBL_Choose_Server_Type'        => 'Choose server type',
	'JSLBL_Other'                     => 'Other',
	'JSLBL_Gmail'                     => 'Gmail',
	'JSLBL_Fastmail'                  => 'Fastmail',
	'JSLBL_Search_For_Email'          => 'Search for email',
	'JSLBL_Nothing_Found'             => 'Nothing found',
	'JSLBL_Delete_Confirm'            =>'Do you want to delete the Emails permanently?',
	'JSLBL_Delete_Mails_Confirm'      =>'Do you want to delete the Emails?',
	'JSLBL_Receipents_Warning_Message'=>'Please select recepients',
	'JSLBL_NO_MATCH'				  => 'No match found',
	'JSLBL_Saving'					=> 'Saving',
	'JSLBL_Failed_To_Save_Mail'		=>	'Failed to save the mail',
	'JSLBL_ATTACHMENT_NOT_DELETED'	=>	'Attachment could not be deleted',
	'JSLBL_UPLOAD_CANCEL'	=> 'Cancel',
	'JSLBL_UPLOAD_DROPFILES'=>'Drop files here to upload',
	'JSLBL_UPLOAD_FILE'=>'Upload',
	'JSLBL_UPLOAD_DELETE'=>'[x]',
	'JSLBL_UPLOAD_FAILED'=>'Failed',
	'JSLBL_FILEUPLOAD_LIMIT_EXCEEDED'=>'File Upload Limit exceeded!!',
	'JSLBL_MAIL_SENT'=>'Mail Sent',
	'JSLBL_EMAIL_FORMAT_INCORRECT'=>'Please provide proper email address',
	'JSLBL_Saving'=>'Saving',
	'JSLBL_SaveWith_EmptySubject'=>'Save with subject empty?',
	'JSLBL_Delete'            =>  'Delete',
	'JSLBL_Drafts'=>'Drafts',
	'JSLBL_PASSWORD_CANNOT_BE_EMPTY'=>'Password cannot be empty',
	'JSLBL_SERVERNAME_CANNOT_BE_EMPTY'=>'Server Name cannot be empty',
	'JSLBL_USERNAME_CANNOT_BE_EMPTY'=>'User Name cannot be empty',
	'JSLBL_ACCOUNTNAME_CANNOT_EMPTY'=>'Organization Name cannot be empty',
	'JSLBL_FROM'=>'From:',
	'JSLBL_DATE'=>'Date: ',
	'JSLBL_SUBJECT'=>'Subject: ',
	'JSLBL_TO'=>'To: ',
	'JSLBL_CC'=>'Cc: ',
	'JSLBL_FORWARD_MESSAGE_TEXT'=>'---------- Forwarded message ----------',
	'JSLBL_PLEASE_SELECT_ATLEAST_ONE_MAIL'=>'Please select at least one mail',
	'JSLBL_PLEASE_SELECT_ATLEAST_ONE_RECORD'=>'Please select at least one record',
	'JSLBL_MAIL_MOVED'=>'Mail(s) moved',
	'JSLBL_MOVING'=>'Moving Mail(s)',
	'JSLBL_LOADING_FOLDERS' => 'Loading Folders..',
	'JSLBL_ADD_COMMENT'=>'Add Comment',
    'JSLBL_Yahoo'=>'Yahoo',
    'JSLBL_CANNOT_ADD_EMPTY_COMMENT' => 'Comment cannot be empty',
    'JSLBL_NO_EMAILS_SELECTED' => 'No Emails Selected.',
    'JSLBL_ENTER_SOME_VALUE' => 'Enter some string to search',
    'JSLBL_DRAFT_MAIL_SAVED'=>'Mail is saved under Drafts',
    
	// General translations
	'LBL_Folders'         => 'Folders',
	'LBL_Newer'           => 'Newer',
	'LBL_Older'           => 'Older',
	'LBL_No_Mails_Found'  => 'No mails found.',
	'LBL_Go_Back'         => 'Back',
	'LBL_Reply_All'       => 'Reply all',
	'LBL_Reply'           => 'Reply',
	'LBL_Mark_As_Unread'  => 'Mark as unread',
	'LBL_Previous'        => 'previous',
	'LBL_Next'            => 'next',
	'LBL_RELATED_RECORDS' => 'Related Records',
	'LBL_Mailbox'         => 'Mailbox',
	'LBL_Outbox'          => 'CRM Outbox',
	'LBL_Like'            => 'like',
	'LBL_Mail_Server'     => 'Mail Server Name or IP',
	'LBL_Refresh'         => 'Refresh',
	'LBL_Cancel'          => 'Cancel',
	'LBL_Send'            => 'Send',
	'LBL_Compose'         => 'Compose',
	'LBL_Forward'         => 'Forward',
	'LBL_Remove'          => 'Remove',
	'LBL_Associate'       => 'Associate',
	'LBL_Create_Contact'  => 'Create contact',
	'LBL_No_Matching_Record_Found' => 'No matching records found.',
	'LBL_ACTIONS'         => 'Actions',
	'LBL_Search'          => 'Search',
	'LBL_Delete'            =>  'Delete',
	
	'LBL_Username'             => 'User Name',
	'LBL_Your_Mailbox_Account' => 'your mailbox account',
	'LBL_Password'             => 'Password',
	'LBL_Account_Password'     => 'account password',
	'LBL_Protocol'    => 'Protocol',
	'LBL_Imap2'       => 'IMAP2',
	'LBL_Imap4'       => 'IMAP4',
	'LBL_SSL_Options' => 'SSL Options',
	'LBL_No_TLS'      => 'No TLS',
	'LBL_TLS'         => 'TLS',
	'LBL_SSL'         => 'SSL',
	'LBL_Certificate_Validations' => 'Certificate Validations',
	'LBL_Validate_Cert'           => 'Validate cert',
	'LBL_Do_Not_Validate_Cert'    => 'Do not validate cert',
	'LBL_SELECT_ACCOUNT_TYPE'     => 'Select Organization Type',
	
	'LBL_FROM'        => 'From',
	'LBL_TO'          => 'To',
	'LBL_CC'          => 'CC',
	'LBL_BCC'         => 'BCC',
	'LBL_Date'        => 'Date',
	'LBL_Attachments' => 'Attachments',
	'LBL_EMAIL_TEMPLATES_LIST'=>'Email Templates',
	'LBL_SELECT_EMAIL_TEMPLATE'=>'Select Email template',
	'LBL_ATTACHMENTS'  =>'Attachment:',
	'LBL_SELECT_DOCUMENTS'=>'Select Documents',
	'LBL_IN' =>'in',
	'LBL_FIND'=>'Find',
	'LBL_SAVE_NOW'=>'Save Now',
	'LBL_Drafts'=>'Drafts',
 	'LBL_NO_EMAILS_SELECTED' => 'No Emails Selected.',
	'LBL_SUBJECT'	=>	'Subject',
	'LBL_WRITE_ACCESS_FOR'	=>'Write access for',
	'LBL_READ_ACCESS_FOR'	=>'Read access for',
	'LBL_MODULE_DENIED' => 'module denied!',
	'LBL_REFRESH_TIME'=>'Refresh Time',
	'LBL_NONE' => 'None',
	'LBL_5_MIN' => '5 Minutes',
	'LBL_10_MIN' => '10 Minutes',
	'LBL_MOVE_TO'=>'Move To...',
    'LBL_MAILMANAGER_ADD_Contacts' => 'Add Contact',
    'LBL_MAILMANAGER_ADD_Accounts' => 'Add Organization',
    'LBL_MAILMANAGER_ADD_Leads' => 'Add Lead',
    'LBL_MAILMANAGER_ADD_Calendar' => 'Add ToDo',
    'LBL_MAILMANAGER_ADD_HelpDesk' => 'Add Ticket',
    'LBL_MAILMANAGER_ADD_Emails' => 'Attach Email',
    'LBL_MAILMANAGER_ADD_ModComments' => 'Add Comment',
    'LBL_ADD' => 'Add',
	'JSLBL_SendWith_EmptyText' => 'Send without text in the body?',
	'LBL_ALLMAILS' => 'All Mails',
	'LBL_TO_CONTACTS' => 'To Contacts',
	'LBL_TO_ACCOUNTS' => 'To Organizations',
	'LBL_TO_LEADS' => 'To Leads',
	'LBL_TO_USERS' => 'To Users',
	'LBL_SENT_MAILS' => 'Sent Mails'
);

?>
